@@ -823,6 +823,51 @@ class Askdata(SignUp):
         # Agent.__init__(self, self, slug=slug)
         return Agent(self, slug=slug, agent_id=agent_id)
 
+    def join(self, df:pd.DataFrame, with_query:str, workspace:str, how="inner", on=None, left_on=None, right_on=None, lang="en"):
+
+        if self._env == 'dev':
+            base_url = url_list['BASE_URL_ASKDATA_DEV']
+        elif self._env == 'qa':
+            base_url = url_list['BASE_URL_ASKDATA_QA']
+        elif self._env == 'prod':
+            base_url = url_list['BASE_URL_ASKDATA_PROD']
+
+        if(on==None and (left_on== None and right_on==None)):
+            logging.error("Pleanse insert either 'on' condition or right_on and left_on conditions!")
+            return
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+        authentication_url = base_url + '/smartbot/agents/agentslug/' + workspace
+
+        headers = {"Authorization": "Bearer" + " " + self._token}
+        response = s.get(url=authentication_url, headers=headers)
+        response.raise_for_status()
+        r = response.json()
+        agent_id = r["agentId"]
+
+        url = base_url + "/smartbot/agents/"+agent_id+"/ask"
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        body = {
+            "message": with_query,
+            "language": lang.lower(),
+            "userId": self.userid
+        }
+
+        response = s.post(url=url, json=body, headers=self._headers)
+        response.raise_for_status()
+        result = response.json()["result"]
+        df_query = pd.DataFrame(data=result[0]["attachment"]["body"][0]["details"]["rows"], columns=result[0]["attachment"]["body"][0]["details"]["columns"])
+
+        return df.merge(df_query, how, on, left_on, right_on)
+
 
     def get(self, query, workspace='', dataset='', lang="en"):
 
